DatePicker class

Inheritance

Constructors

DatePicker(DateTime startDate, {Key? key, double width = 60, double height = 80, DatePickerController? controller, TextStyle monthTextStyle = defaultMonthTextStyle, TextStyle dayTextStyle = defaultDayTextStyle, TextStyle dateTextStyle = defaultDateTextStyle, Color selectedTextColor = Colors.white, Color selectionColor = AppColors.defaultSelectionColor, Color deactivatedColor = AppColors.defaultDeactivatedColor, DateTime? initialSelectedDate, List<DateTime>? activeDates, List<DateTime>? inactiveDates, int daysCount = 500, DateChangeListener? onDateChange, String locale = "en_US"})

Properties

activeDates → List<DateTime>?
Contains the list of active dates. Only the dates in this list will be activated.
final
controller → DatePickerController?
DatePicker Controller
final
dateTextStyle → TextStyle
TextStyle for the date Value
final
daysCount → int
Max limit up to which the dates are shown. Days are counted from the startDate
final
dayTextStyle → TextStyle
TextStyle for day Value
final
deactivatedColor → Color
Text Color for the deactivated dates
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
Height of the selector
final
inactiveDates → List<DateTime>?
Contains the list of inactive dates. All the dates defined in this List will be deactivated
final
initialSelectedDate → DateTime?
Current Selected Date
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
locale → String
Locale for the calendar default: en_us
final
monthTextStyle → TextStyle
TextStyle for Month Value
final
onDateChange → DateChangeListener?
Callback function for when a different date is selected
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedTextColor → Color
Text color for the selected Date
final
selectionColor → Color
Background color for the selector
final
startDate → DateTime
Start Date in case user wants to show past dates If not provided calendar will start from the initialSelectedDate
final
width → double
Width of the selector
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited